@@ -10,6 +10,18 @@ from .constants import APP_CHARSET, IS_PYTHON_3
 from .services import REDIS_INSTANCES
 
 
+class StreamArray(list):
+    def __init__(self, gen, *args):
+        self.gen = gen
+        self.args = args
+
+    def __iter__(self):
+        return self.gen(*self.args)
+
+    def __len__(self):
+        return 1
+
+
 class Redis():
     """
     Modificació de StrictRedis per poder instanciar de
@@ -38,22 +50,24 @@ class Redis():
         pass
 
     def keys(self, command):
-        def _gen(command):
-            r = random.randint(0, 1000)
-            while r >= 2:
+        def _gen():
+            r = random.randint(0, 100)
+            while r >= 5:
+                r = random.randint(0, 100)
                 yield (str(random.randint(1, 10)) + ":" +
                        str(random.randint(1, 5000)) + ":" +
                        str(random.choice(["v", "d", "tp", "e", "ep", "t", "u"])))
 
-        return _gen(command)
+        return StreamArray(_gen)
 
     def hgetall(self, command):
-        def _gen(command):
-            r = random.randint(0, 1000)
-            while r >= 2:
+        def _gen():
+            r = random.randint(0, 100)
+            while r >= 5:
+                r = random.randint(0, 100)
                 yield {random.randint(1, 10): random.randint(0, 3000)}
 
-        return _gen(command)
+        return StreamArray(_gen)
 
     def set(self, *args):
         pass
